==> jc-1.4.0.tar.gz: java/util/zip/Adler32.h <==
// public class java.util.zip.Adler32

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e402919c0142085c java_util_zip_Adler32

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_Adler32_H_
#define _JC_java_util_zip_Adler32_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_Adler32$sub_refs	_jc_java_util_zip_Adler32$sub_refs;
typedef struct _jc_java_util_zip_Adler32$sub_nonrefs	_jc_java_util_zip_Adler32$sub_nonrefs;
typedef struct _jc_java_util_zip_Adler32$refs	_jc_java_util_zip_Adler32$refs;
typedef struct _jc_java_util_zip_Adler32$nonrefs	_jc_java_util_zip_Adler32$nonrefs;
typedef struct _jc_java_util_zip_Adler32$object	_jc_java_util_zip_Adler32$object;

typedef struct _jc_java_util_zip_Adler32$fields_struct	_jc_java_util_zip_Adler32$fields_struct;
typedef const struct _jc_java_util_zip_Adler32$vmethods	_jc_java_util_zip_Adler32$vmethods;
typedef const struct _jc_java_util_zip_Adler32$vtable	_jc_java_util_zip_Adler32$vtable;
typedef const struct _jc_java_util_zip_Adler32$vtype	_jc_java_util_zip_Adler32$vtype;

// Class fields structure
struct _jc_java_util_zip_Adler32$fields_struct {
	jint	BASE;
};
extern _jc_java_util_zip_Adler32$fields_struct _jc_java_util_zip_Adler32$class_fields;

// Constructors
extern void _jc_java_util_zip_Adler32$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_Adler32$object *);

// Virtual methods
extern jlong _jc_java_util_zip_Adler32$method$getValue$738f22e2bb5f71e8(_jc_env *, struct _jc_java_util_zip_Adler32$object *);
extern void _jc_java_util_zip_Adler32$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_util_zip_Adler32$object *);
extern void _jc_java_util_zip_Adler32$method$update$469c8c2dea465a16(_jc_env *, struct _jc_java_util_zip_Adler32$object *, jint);
extern void _jc_java_util_zip_Adler32$method$update$3e1f8b534704abb5(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *);
extern void _jc_java_util_zip_Adler32$method$update$f73f1b3bfa3ea853(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_Adler32$method_info$getValue$738f22e2bb5f71e8;
extern _jc_method _jc_java_util_zip_Adler32$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$469c8c2dea465a16;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$3e1f8b534704abb5;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$f73f1b3bfa3ea853;

// Virtual methods structure
struct _jc_java_util_zip_Adler32$vmethods {
	jlong	(*getValue$738f22e2bb5f71e8)(_jc_env *, struct _jc_java_util_zip_Adler32$object *);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_util_zip_Adler32$object *);
	void	(*update$469c8c2dea465a16)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, jint);
	void	(*update$3e1f8b534704abb5)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *);
	void	(*update$f73f1b3bfa3ea853)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_util_zip_Adler32$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_Adler32$vmethods	java_util_zip_Adler32;
};

// Vtype
struct _jc_java_util_zip_Adler32$vtype {
	_jc_type			type;
	_jc_java_util_zip_Adler32$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_Adler32$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_zip_Adler32$refs {
    _jc_java_util_zip_Adler32$sub_refs	java_util_zip_Adler32;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_Adler32$sub_nonrefs {
	jint	checksum;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_Adler32$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_Adler32$sub_nonrefs	java_util_zip_Adler32;
};

// Object instance structure
struct _jc_java_util_zip_Adler32$object {
	_jc_java_util_zip_Adler32$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_Adler32$vtype	*vtype;
	_jc_java_util_zip_Adler32$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_Adler32$vtype _jc_java_util_zip_Adler32$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_Adler32, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_Adler32$class_object;

#endif	/* _JC_java_util_zip_Adler32_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/Adler32.h <==
// public class java.util.zip.Adler32

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e402919c0142085c java_util_zip_Adler32

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_Adler32_H_
#define _JC_java_util_zip_Adler32_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_Adler32$sub_refs	_jc_java_util_zip_Adler32$sub_refs;
typedef struct _jc_java_util_zip_Adler32$sub_nonrefs	_jc_java_util_zip_Adler32$sub_nonrefs;
typedef struct _jc_java_util_zip_Adler32$refs	_jc_java_util_zip_Adler32$refs;
typedef struct _jc_java_util_zip_Adler32$nonrefs	_jc_java_util_zip_Adler32$nonrefs;
typedef struct _jc_java_util_zip_Adler32$object	_jc_java_util_zip_Adler32$object;

typedef struct _jc_java_util_zip_Adler32$fields_struct	_jc_java_util_zip_Adler32$fields_struct;
typedef const struct _jc_java_util_zip_Adler32$vmethods	_jc_java_util_zip_Adler32$vmethods;
typedef const struct _jc_java_util_zip_Adler32$vtable	_jc_java_util_zip_Adler32$vtable;
typedef const struct _jc_java_util_zip_Adler32$vtype	_jc_java_util_zip_Adler32$vtype;

// Class fields structure
struct _jc_java_util_zip_Adler32$fields_struct {
	jint	BASE;
};
extern _jc_java_util_zip_Adler32$fields_struct _jc_java_util_zip_Adler32$class_fields;

// Constructors
extern void _jc_java_util_zip_Adler32$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_Adler32$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jlong _jc_java_util_zip_Adler32$method$getValue$738f22e2bb5f71e8(_jc_env *, struct _jc_java_util_zip_Adler32$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_Adler32$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_util_zip_Adler32$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_Adler32$method$update$469c8c2dea465a16(_jc_env *, struct _jc_java_util_zip_Adler32$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_Adler32$method$update$3e1f8b534704abb5(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_Adler32$method$update$f73f1b3bfa3ea853(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_Adler32$method_info$getValue$738f22e2bb5f71e8;
extern _jc_method _jc_java_util_zip_Adler32$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$469c8c2dea465a16;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$3e1f8b534704abb5;
extern _jc_method _jc_java_util_zip_Adler32$method_info$update$f73f1b3bfa3ea853;

// Virtual methods structure
struct _jc_java_util_zip_Adler32$vmethods {
	jlong	(*getValue$738f22e2bb5f71e8)(_jc_env *, struct _jc_java_util_zip_Adler32$object *) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_util_zip_Adler32$object *) _JC_JCNI_ATTR;
	void	(*update$469c8c2dea465a16)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, jint) _JC_JCNI_ATTR;
	void	(*update$3e1f8b534704abb5)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*update$f73f1b3bfa3ea853)(_jc_env *, struct _jc_java_util_zip_Adler32$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_Adler32$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_Adler32$vmethods	java_util_zip_Adler32;
};

// Vtype
struct _jc_java_util_zip_Adler32$vtype {
	_jc_type			type;
	_jc_java_util_zip_Adler32$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_Adler32$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_zip_Adler32$refs {
    _jc_java_util_zip_Adler32$sub_refs	java_util_zip_Adler32;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_Adler32$sub_nonrefs {
	jint	checksum;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_Adler32$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_Adler32$sub_nonrefs	java_util_zip_Adler32;
};

// Object instance structure
struct _jc_java_util_zip_Adler32$object {
	_jc_java_util_zip_Adler32$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_Adler32$vtype	*vtype;
	_jc_java_util_zip_Adler32$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_Adler32$vtype _jc_java_util_zip_Adler32$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_Adler32, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_Adler32$class_object;

#endif	/* _JC_java_util_zip_Adler32_H_ */
